# -*- coding: utf-8 -*-
## This module contains all article model inerfaces
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
This module contains all article model interfaces
"""

__docformat__ = 'restructuredtext'

# Zope imports
from zope.interface import Interface, Attribute
from plone.app.layout.navigation.interfaces import IDefaultPage

class IPloneArticleMultipageView(Interface):
    """View for articles containers"""

    def isMultipage(self):
        """True if in a multipage context"""

    def getPages(self):
        """Return pages as catalog brains"""

    def getTOCItems(self, context=None):
        """return a structure for display the TOC menu"""

    def getPreviousPage(self, context):
        """Catalog brain of the previous page of context"""

    def getNextPage(self, context):
        """Catalog brain of the next page of context"""

class IExplorerView(Interface):
    """View for explorer (for referencing content in articles)

    The request should have 'current_article', 'field_name' parameters
    """

    def getFolders(self):
        """Return a list of folders brain in context
        """

    def getReferenceableContent(self):
        """Return a list of brains for content that are referenceable for the
        current field"""

    def isImage(self, obj):
        """obj implements IImageContent"""

    def getThumbNailTagFor(self, image):
        """Return a proper img thumbnail tag for given image object"""

    def getOrientationFor(self, image):
        """Return orientation class for given image object"""
        
class IPloneArticleSelectModelView(Interface):
    """View for the 'select model' page"""

    def getSelectableModels(self):
        """return a list of dict with id, title, description and icon values"""

class IPloneArticleModelView(Interface):
    """View for all article models"""

    template_id = Attribute('template_id',
                            'Must be set to a unique template name')

    title = Attribute('title',
                      'The user friendly title of this model')
    
    def getImageUrl(proxy):
        """Returns url to access image of an ImageInnerContentProxy object"""
    
    def getImageTag(proxy):
        """Returns an img tag rendering an ImageInnerContentProxy object"""
    
    def getImageTile(proxy):
        """Returns a 16px icon from an ImageInnerContentProxy object"""
    
    def getBigImageTag(proxy):
        """Returns a big img tag rendering an ImageInnerContentProxy object"""
    
    def getImage4Crop(proxy):
        """Returns a 250px img tag from an ImageInnerContentProxy object"""
    
    def getSmallImage4Crop(proxy):
        """Returns a 50px img tag from an ImageInnerContentProxy object"""
        
    def getImageBlockStyle(proxy):
        """Returns style of block containing the img tag rendering an ImageInnerContentProxy object"""
    
    def getFileUrl(proxy):
        """Returns url to access file of an FileInnerContentProxy object"""
        
    
class IPloneArticleModel1View(Interface):
    """View for article model 1"""
    
class IPloneArticleModel2View(Interface):
    """View for article model 2"""

    def getFirstImage(self):
        pass

    def getOtherImages(self):
        pass
    
class IPloneArticleModel3View(Interface):
    """View for article model 3"""

class IPloneArticleModel4View(Interface):
    """View for article model 4"""

class IPloneArticleModel5View(Interface):
    """View for article model 5"""

    def getHeadingImages(self):
        pass

    def getBodyImages(self):
        pass

class IPloneArticleModel6View(Interface):
    """View for article model 6"""

    def getFirstImage(self):
        pass

    def getOtherImages(self):
        pass

class IPloneArticleModel7View(Interface):
    """View for article model 7"""

    def getFirstImage(self):
        pass

    def getOtherImages(self):
        pass

class IPloneArticleModel8View(Interface):
    """View for article model 8"""

    def getFirstImage(self):
        pass

    def getOtherImages(self):
        pass

class IPloneArticleModel9View(Interface):
    """View for article model 9"""        
    
    
class IPloneArticleModel10View(Interface):
    """View for article model 10"""

    def getFirstImage(self):
        pass

    def getHeadingImages(self):
        pass
        
class IPloneArticleModel11View(Interface):
    """View for article model 11"""


    def getPlayerImages(self):
        pass

    def getPlayerStyle(self):
        pass    

    def getPlayerFirstImage(self):
        pass    



# -*- coding: utf-8 -*-
## Product description
## 
## Copyright (C) 2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
Model management views
"""

__docformat__ = 'restructuredtext'

# Zope imports
from zope.interface import implements
from Products.Five import BrowserView

# CMF
from Products.CMFCore.utils import getToolByName

# Products imports
from interface import IPloneArticleSelectModelView
from Products.PloneArticle.model import getModelRegistry

from Products.PloneArticle.i18n import ModelMessageFactory as _

class SelectModelView(BrowserView):
    implements(IPloneArticleSelectModelView)

    def __init__(self, context, request):
        self.context = context
        self.request = request

    def getSelectableModels(self):
        model_ids = self.context.getAvailableLayouts()
        registry = getModelRegistry()
        result = []
        for model_id, utitle in model_ids:
            model = registry.get(model_id, None)
            if model is None:
                continue
            description = _(model.description_msgid, default=model.description)
            result.append({
                'id': model.id,
                'title': model.Title(),
                'description': description,
                'icon': model.icon,
                })
        return result
   



# -*- coding: utf-8 -*-
## Copyright (C)2007 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

"""
Our view classes
$Id$
"""

from zope.interface import implements
from Products.CMFCore.utils import getToolByName
from Products.Five import BrowserView

# Root view class for PloneArticle (Five.BrowseView subclass)
from Products.PloneArticle.browser.article import PloneArticleModelView

# Unregistered viws are useless ;)
from Products.PloneArticle.model import registerArticleModel

# Importing our model interfaces
from interface import IPAViewWithAuthor

# You should now take a look at Products/PloneArticle/browser/article.py
# to see what's already publicly available.
# Other points of interest for your view class are:
# * ATDocument of ATContentTypes: PloneArticle inherits from this type
# * Products/PloneArticle/content/*.py: PloneArticle schema and resources
# * Products/PloneArticle/field/*.py: How we access inner content (files, images)

class PAViewWithAuthor(PloneArticleModelView):
    # Note that the docstring is used as default description of our model.
    """
    Like the documentation view, but adds the portrait of the author
    at the top left of the article.
    """

    implements(IPAViewWithAuthor)

    template_id = 'author_pa_model' # Your layer directory must have 'my_pa_model.pt'
    title = u"Documentation model with author portrait" # Always Unicode and english
    title_msgid = 'author_model_title' # See mypamodel/i18n
    description_msgid = 'author_model_description' # See mypamodel/i18n/*
    icon = 'author_pa_model.png' # Your layer directory must have this picture

    def authorInfo(self):
        """
        See IPAViewWithAuthor
        """

        context = self.context
        portal_membership = getToolByName(context, 'portal_membership')
        portal_url = getToolByName(context, 'portal_url')()
        creator = context.Creator()
        info = portal_membership.getMemberInfo(creator)
        return {
            'fullname': info and info['fullname'] or creator,
            'url': '%s/author/%s' % (portal_url, creator),
            'portrait': portal_membership.getPersonalPortrait(creator)
            }
        


# Unregistered views cannot selected by author
registerArticleModel(PAViewWithAuthor)
